@@ -5,7 +5,7 @@ use warnings;
 
 use MooX::ReturnModifiers;
 
-our $VERSION = '1.012002';
+our $VERSION = '1.012003';
 
 sub import {
 	my $target	= caller;
@@ -26,8 +26,6 @@ sub import {
 							my ( $orig, $self, @params ) = @_;
 							my $current_spec = $self->$store_spec;
 
-							@params = $self->_preprocess_params(@params);
-
 							if ( my $param_spec = $current_spec->{params} ) {
 								@params = $self->_validate_sub(
 									$name, 'params', $param_spec, @params
@@ -75,7 +73,7 @@ MooX::ValidateSubs - Validating sub routines via Type::Tiny.
 
 =head1 VERSION
 
-Version 1.012002
+Version 1.012003
 
 =cut
 
@@ -139,7 +137,7 @@ Version 1.012002
 		return %args;
 	}
 
-	$self->indexed('2=changed'); # one, two, changed
+	$self->indexed(2 => 'changed'); # one, two, changed
 
 =head1 Exports
 
